EpubByteContentFileRef class

Constructors

EpubByteContentFileRef(EpubBookRef epubBookRef)

Properties

ContentMimeType String?
getter/setter pairinherited
ContentType EpubContentType?
getter/setter pairinherited
epubBookRef EpubBookRef
getter/setter pairinherited
FileName String?
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getContentFileEntry() → ArchiveFile
inherited
getContentStream() List<int>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openContentStream(ArchiveFile contentFileEntry) List<int>
inherited
readContent() Future<List<int>>
readContentAsBytes() Future<Uint8List>
inherited
readContentAsText() Future<String>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited